@@ -161,9 +161,14 @@ void KalendarAlarmClient::showIncidence(const QString &uid, const QDateTime &occ
 
 void KalendarAlarmClient::storeNotification(AlarmNotification *notification)
 {
+    // Work around crashing when feeding a QString to the KConfigGroup constructor for the config group name
+    // BUG: 456157
+    const auto notificationUidUtf8 = notification->uid().toUtf8();
+    const auto notificationUidData = notificationUidUtf8.constData();
+
     KConfigGroup suspendedGroup(KSharedConfig::openConfig(), "Suspended");
-    KConfigGroup notificationGroup(&suspendedGroup, notification->uid());
-    notificationGroup.writeEntry("UID", notification->uid());
+    KConfigGroup notificationGroup(&suspendedGroup, notificationUidData);
+    notificationGroup.writeEntry("UID", notificationUidData);
     notificationGroup.writeEntry("Text", notification->text());
     if (notification->occurrence().isValid()) {
         notificationGroup.writeEntry("Occurrence", notification->occurrence());
@@ -174,8 +179,13 @@ void KalendarAlarmClient::storeNotification(AlarmNotification *notification)
 
 void KalendarAlarmClient::removeNotification(AlarmNotification *notification)
 {
+    // Work around crashing when feeding a QString to the KConfigGroup constructor for the config group name
+    // BUG: 456157
+    const auto notificationUidUtf8 = notification->uid().toUtf8();
+    const auto notificationUidData = notificationUidUtf8.constData();
+
     KConfigGroup suspendedGroup(KSharedConfig::openConfig(), "Suspended");
-    KConfigGroup notificationGroup(&suspendedGroup, notification->uid());
+    KConfigGroup notificationGroup(&suspendedGroup, notificationUidData);
     notificationGroup.deleteGroup();
     KSharedConfig::openConfig()->sync();
 }
@@ -262,7 +272,7 @@ void KalendarAlarmClient::checkAlarms()
         const auto notification = it.value();
 
         // Protect against null ptr
-        if(!notification) {
+        if (!notification) {
             qCDebug(Log) << "Found null active alarm with id: " << it.key() << "Skipping.";
             nullAlarmNotificationIds.append(it.key());
             continue;
@@ -277,7 +287,7 @@ void KalendarAlarmClient::checkAlarms()
     }
 
     // Remove the null alarm notification ptrs from our notifications
-    for(const auto &nullAlarmId : nullAlarmNotificationIds) {
+    for (const auto &nullAlarmId : nullAlarmNotificationIds) {
         m_notifications.remove(nullAlarmId);
     }
 
@@ -298,12 +308,8 @@ void KalendarAlarmClient::saveLastCheckTime()
 QDateTime
 KalendarAlarmClient::occurrenceForAlarm(const KCalendarCore::Incidence::Ptr &incidence, const KCalendarCore::Alarm::Ptr &alarm, const QDateTime &from) const
 {
-    if (!incidence->recurs()) {
-        return {};
-    }
-
     // recurring alarms not handled here for simplicity
-    if (alarm->repeatCount()) {
+    if (incidence.isNull() || !incidence->recurs() || alarm->repeatCount()) {
         return {};
     }
 
